@@ -1,19 +1,21 @@
 import logging
-from custom_python_logger import get_logger
+
+from custom_python_logger import build_logger, get_logger
 
 
 class LoggerTest:
     def __init__(self):
-        self.logger = logging.getLogger(self.__class__.__name__)
+        self.logger = get_logger(self.__class__.__name__)
 
     def main(self):
-        self.logger.info('Hello World')
-        self.logger.debug('Hello World')
+        self.logger.debug("Hello World")
+        self.logger.info("Hello World")
+        self.logger.step("Hello World")
 
 
 def main():
-    logger = get_logger(
-        project_name='Logger Project Test',
+    logger = build_logger(
+        project_name="Logger Project Test",
         log_level=logging.DEBUG,
         log_file=True,
         # extra={'user': 'test_user'}
@@ -35,5 +37,5 @@ def main():
     logger_test.main()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
