@@ -1,20 +1,20 @@
 import unittest
-from custom_python_logger import get_logger
+from custom_python_logger import build_logger
 
 
 class TestLogger(unittest.TestCase):
     def test_logger_creation(self):
-        logger = get_logger(project_name='TestProject')
+        logger = build_logger(project_name='TestProject')
         self.assertIsNotNone(logger)
         self.assertEqual(logger.name, 'root')
 
     def test_step_log(self):
-        logger = get_logger(project_name='TestProject')
+        logger = build_logger(project_name='TestProject')
         logger.step('Testing step log')
         self.assertTrue(True)  # You can add more specific checks for actual logging output
 
     def test_exception_log(self):
-        logger = get_logger(project_name='TestProject')
+        logger = build_logger(project_name='TestProject')
         try:
             raise ValueError("Test exception")
         except ValueError as e:
